@@ -48,7 +48,6 @@ class Client(object):
         personal_api_key=None,
         project_api_key=None,
     ):
-
         self.queue = queue.Queue(max_queue_size)
 
         # api_key: This should be the Team API Key (token), public
@@ -66,6 +65,7 @@ class Client(object):
         self.feature_flags = None
         self.feature_flags_by_key = None
         self.group_type_mapping = None
+        self.cohorts = None
         self.poll_interval = poll_interval
         self.poller = None
         self.distinct_ids_feature_flags_reported = SizeLimitedDict(MAX_DICT_SIZE, set)
@@ -131,6 +131,12 @@ class Client(object):
         resp_data = self.get_decide(distinct_id, groups, person_properties, group_properties)
         return resp_data["featureFlags"]
 
+    def _get_active_feature_variants(self, distinct_id, groups=None, person_properties=None, group_properties=None):
+        feature_variants = self.get_feature_variants(distinct_id, groups, person_properties, group_properties)
+        return {
+            k: v for (k, v) in feature_variants.items() if v is not False
+        }  # explicitly test for false to account for values that may seem falsy (ex: 0)
+
     def get_feature_payloads(self, distinct_id, groups=None, person_properties=None, group_properties=None):
         resp_data = self.get_decide(distinct_id, groups, person_properties, group_properties)
         return resp_data["featureFlagPayloads"]
@@ -150,6 +156,8 @@ class Client(object):
             "group_properties": group_properties,
         }
         resp_data = decide(self.api_key, self.host, timeout=10, **request_data)
+
+        print(resp_data)
         return resp_data
 
     def capture(
@@ -184,7 +192,7 @@ class Client(object):
 
         if send_feature_flags:
             try:
-                feature_variants = self.get_feature_variants(distinct_id, groups)
+                feature_variants = self._get_active_feature_variants(distinct_id, groups)
             except Exception as e:
                 self.log.exception(f"[FEATURE FLAGS] Unable to get feature variants: {e}")
             else:
@@ -367,10 +375,9 @@ class Client(object):
 
     def _load_feature_flags(self):
         try:
-
             response = get(
                 self.personal_api_key,
-                f"/api/feature_flag/local_evaluation/?token={self.api_key}",
+                f"/api/feature_flag/local_evaluation/?token={self.api_key}&send_cohorts",
                 self.host,
                 timeout=10,
             )
@@ -380,15 +387,20 @@ class Client(object):
                 flag["key"]: flag for flag in self.feature_flags if flag.get("key") is not None
             }
             self.group_type_mapping = response["group_type_mapping"] or {}
+            self.cohorts = response["cohorts"] or {}
 
         except APIError as e:
             if e.status == 401:
-                raise APIError(
-                    status=401,
-                    message="You are using a write-only key with feature flags. "
-                    "To use feature flags, please set a personal_api_key "
-                    "More information: https://posthog.com/docs/api/overview",
+                self.log.error(
+                    f"[FEATURE FLAGS] Error loading feature flags: To use feature flags, please set a valid personal_api_key. More information: https://posthog.com/docs/api/overview"
                 )
+                if self.debug:
+                    raise APIError(
+                        status=401,
+                        message="You are using a write-only key with feature flags. "
+                        "To use feature flags, please set a personal_api_key "
+                        "More information: https://posthog.com/docs/api/overview",
+                    )
             else:
                 self.log.error(f"[FEATURE FLAGS] Error loading feature flags: {e}")
         except Exception as e:
@@ -412,7 +424,6 @@ class Client(object):
             self.poller.start()
 
     def _compute_flag_locally(self, feature_flag, distinct_id, *, groups={}, person_properties={}, group_properties={}):
-
         if feature_flag.get("ensure_experience_continuity", False):
             raise InconclusiveMatchError("Flag has experience continuity enabled")
 
@@ -442,7 +453,7 @@ class Client(object):
             focused_group_properties = group_properties[group_name]
             return match_feature_flag_properties(feature_flag, groups[group_name], focused_group_properties)
         else:
-            return match_feature_flag_properties(feature_flag, distinct_id, person_properties)
+            return match_feature_flag_properties(feature_flag, distinct_id, person_properties, self.cohorts)
 
     def feature_enabled(
         self,
